@@ -4,19 +4,30 @@ base_path <- "c:\\packages\\libr\\tests\\testthat\\data"
 
 base_path <- "./data"
 
+DEV <- FALSE
 
 test_that("print() functions works as expected.", {
   
+  if (DEV) {
 
   libname(dat, base_path, engine = "csv")
 
   
-  # Just run the print functions and make sure there is no errors.
-  #print(dat)
-  #print(dat, verbose = TRUE)
   dat
   
-  expect_equal(TRUE, TRUE)
+  expect_equal(is.lib(dat), TRUE)
+  
+  res <- capture.output(print(dat))
+  
+  expect_equal(length(res) > 0, TRUE)
+  
+  
+  res2 <- capture.output(print(dat, verbose = TRUE))
+  
+  expect_equal(length(res2) > 0, TRUE)
+  
+  } else 
+    expect_equal(TRUE, TRUE)
   
 })
 
@@ -132,6 +143,24 @@ test_that("copy_attributes function works as expected.", {
   
 })
 
+
+test_that("equality operators are working as expected.", {
+  
+  
+  expect_equal(NULL %eq% NULL, TRUE)
+  expect_equal(NULL %eq% "fork", FALSE)
+  expect_equal(1 %eq% "fork", FALSE)
+  
+  
+  expect_equal(data.frame(A = 1, 
+                          stringsAsFactors = FALSE) %eq% data.frame(B = 1, 
+                          stringsAsFactors = FALSE), FALSE)
+  
+  expect_equal(strong_eq(1 , "fork"), FALSE)
+  
+  
+})
+
 # 
 # test_that("libname() var_name parameter works as expected.", {
 #   
